// Copyright (C) 2020 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QTSVGWIDGETSGLOBAL_H
#define QTSVGWIDGETSGLOBAL_H

#include <QtCore/qglobal.h>
#include <QtSvgWidgets/qtsvgwidgetsexports.h>
#include <QtSvg/qtsvgglobal.h>

#endif
